@@ -1,4 +1,4 @@
-"ensembleGroups" <-
+`ensembleGroups` <-
 function(x) 
 UseMethod("ensembleGroups")
 
