@@ -1,4 +1,4 @@
-"ensembleMemberLabels" <-
+`ensembleMemberLabels` <-
 function (x) 
 UseMethod("ensembleMemberLabels")
 
