@@ -1,4 +1,4 @@
-"ensembleObsLabels.ensembleData" <-
+`ensembleObsLabels.ensembleData` <-
 function (x) 
 {
  dimnames(x)[[1]]
